@@ -254,11 +254,11 @@ class Code(ModelSQL, ModelView):
         return res
 
     def search_rec_name(self, cursor, user, name, clause, context=None):
-        ids = self.search(cursor, user, [('code',) + clause[1:]], limit=1,
+        ids = self.search(cursor, user, [('code',) + tuple(clause[1:])], limit=1,
                 order=[], context=context)
         if ids:
-            return [('code',) + clause[1:]]
-        return [('name',) + clause[1:]]
+            return [('code',) + tuple(clause[1:])]
+        return [('name',) + tuple(clause[1:])]
 
     def delete(self, cursor, user, ids, context=None):
         if isinstance(ids, (int, long)):
